@@ -91,6 +91,9 @@ impl Column {
             },
             ColumnType::DateTime(_) => quote! { ColumnType::DateTime.def() },
             ColumnType::Timestamp(_) => quote! { ColumnType::Timestamp.def() },
+            ColumnType::TimestampWithTimeZone(_) => {
+                quote! { ColumnType::TimestampWithTimeZone.def() }
+            }
             ColumnType::Time(_) => quote! { ColumnType::Time.def() },
             ColumnType::Date => quote! { ColumnType::Date.def() },
             ColumnType::Binary(_) => quote! { ColumnType::Binary.def() },
@@ -106,6 +109,7 @@ impl Column {
                 let s = s.to_string();
                 quote! { ColumnType::Custom(#s.to_owned()).def() }
             }
+            #[allow(unreachable_patterns)]
             _ => unimplemented!(),
         };
         if !self.not_null {
